@@ -1,8 +1,9 @@
 /**
- * preferences.h: Controlling the programme's behaviour.
+ * preferences.h: Preferences parsing
  *
  * ==================================================================
- * Copyright (c) 2005-2006 Jonathan Coome.
+ * Copyright (c) 2009-2013 Christoph Mende <mende.christoph@gmail.com>
+ * Based on Jonathan Coome's work on scmpc
  *
  * This file is part of scmpc.
  *
@@ -22,23 +23,41 @@
  * ==================================================================
  */
 
-struct preferences {
-	char *mpd_hostname;
-	int mpd_port;
-	int mpd_timeout;
-	char *mpd_password;
-	bool fork;
-	enum loglevel log_level;
-	char *config_file;
-	char *log_file;
-	char *pid_file;
-	char *as_username;
-	char *as_password;
-	char *as_password_hash;
-	char *cache_file;
-	int queue_length;
-	int cache_interval;
+
+#ifndef HAVE_PREFERENCES_H
+#define HAVE_PREFERENCES_H
+
+#include <glib.h>
+
+/**
+ * scmpc settings
+ */
+struct {
+	gchar *mpd_hostname;
+	gushort mpd_port;
+	gushort mpd_timeout;
+	gchar *mpd_password;
+	gboolean fork;
+	GLogLevelFlags log_level;
+	gchar *config_file;
+	gchar *log_file;
+	gchar *pid_file;
+	gchar *as_username;
+	gchar *as_password;
+	gchar *as_password_hash;
+	gchar *cache_file;
+	guint queue_length;
+	guint cache_interval;
 } prefs;
 
-void init_preferences(int argc, char **argv);
+/**
+ * Initialize preferences
+ */
+gboolean init_preferences(gint argc, gchar *argv[]);
+
+/**
+ * Release resources
+ */
 void clear_preferences(void);
+
+#endif /* HAVE_PREFERENCES_H */
