@@ -1,8 +1,9 @@
 /**
- * main.h: The front end of the programme.
+ * scmpc.h: The front end of the program.
  *
  * ==================================================================
- * Copyright (c) 2005-2006 Jonathan Coome.
+ * Copyright (c) 2009-2013 Christoph Mende <mende.christoph@gmail.com>
+ * Based on Jonathan Coome's work on scmpc
  *
  * This file is part of scmpc.
  *
@@ -23,11 +24,24 @@
  */
 
 
+#ifndef HAVE_SCMPC_H
+#define HAVE_SCMPC_H
+
+#include <glib.h>
+
 /**
- * end_program()
- *
- * This function is used by other threads to signal the main thread to end the
- * program. It's more reliable than trying to send a SIGKILL signal to the pid
- * of the thread.
+ * Exit a running scmpc instance
  */
-void end_program(void);
+void kill_scmpc(void);
+
+/**
+ * Exit the current scmpc instance
+ */
+void scmpc_shutdown(void);
+
+/**
+ * Check if a song is eligible for submission and add it to the queue
+ */
+gboolean scmpc_check(gpointer data);
+
+#endif /* HAVE_SCMPC_H */
